==> ORBit-0.1.tar.gz: ORBit-0.1/src/orb/corba_sequences.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  ORBit: A CORBA v2.2 ORB
 *
 *  Copyright (C) 1998 Richard H. Porter
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Author: Dick Porter <dick@cymru.net>
 *
 */

#ifndef _ORBIT_CORBA_SEQUENCES_H_
#define _ORBIT_CORBA_SEQUENCES_H_


/* moved from sequences.h */

#define _typedef___CORBA_sequence_Identifier
typedef struct CORBA_sequence_Identifier CORBA_sequence_Identifier;

#define _typedef___CORBA_sequence_octet
typedef struct CORBA_sequence_octet CORBA_sequence_octet;
typedef struct CORBA_sequence_octet CORBA_ReferenceData;

#define _typedef___CORBA_sequence_ServiceOption
typedef struct CORBA_sequence_ServiceOption CORBA_sequence_ServiceOption;

#define _typedef___CORBA_sequence_ServiceDetail
typedef struct CORBA_sequence_ServiceDetail CORBA_sequence_ServiceDetail;

#define _typedef___CORBA_sequence_ORB_ObjectId
typedef struct CORBA_sequence_ORB_ObjectId CORBA_ORB_ObjectIdList;

#define _typedef___CORBA_sequenceNameValuePair
typedef struct CORBA_sequence_NameValuePair CORBA_NameValuePairSeq;

#define _typedef___CORBA_sequence_InterfaceDef
typedef struct CORBA_sequence_InterfaceDef CORBA_InterfaceDefSeq;

#define _typedef___CORBA_sequence_ContainedSeq
typedef struct CORBA_sequence_ContainedSeq CORBA_ContainedSeq;

#define _typedef___CORBA_sequence_Container_Description
typedef struct CORBA_sequence_Container_Description CORBA_Container_DescriptionSeq;

#define _typedef___CORBA_sequence_StructMember
typedef struct CORBA_sequence_StructMember CORBA_StructMemberSeq;

#define _typedef___CORBA_sequence_UnionMember
typedef struct CORBA_sequence_UnionMember CORBA_UnionMemberSeq;

#define _typedef___CORBA_sequence_CORBA_any
typedef struct CORBA_sequence_CORBA_any CORBA_AnySeq;

#define _typedef___CORBA_sequence_ParameterDescription
typedef struct CORBA_sequence_ParameterDescription CORBA_ParDescriptionSeq;

#define _typedef___CORBA_sequence_ContextIdentifier
typedef struct CORBA_sequence_ContextIdentifier CORBA_ContextIdSeq;

#define _typedef___CORBA_sequence_ExceptionDef
typedef struct CORBA_sequence_ExceptionDef CORBA_ExceptionDefSeq;

#define _typedef___CORBA_sequence_ExceptionDescription
typedef struct CORBA_sequence_ExceptionDescription CORBA_ExcDescriptionSeq;

#define _typedef___CORBA_sequence_RepositoryId
typedef struct CORBA_sequence_RepositoryId CORBA_RepositoryIdSeq;

#define _typedef___CORBA_sequence_OperationDescription
typedef struct CORBA_sequence_OperationDescription CORBA_OpDescriptionSeq;

#define _typedef___CORBA_sequence_AttributeDescription
typedef struct CORBA_sequence_AttributeDescription CORBA_AttrDescriptionSeq;

#define _typedef___CORBA_sequence_Policy
typedef struct CORBA_sequence_Policy CORBA_PolicyList;

#define _typedef___CORBA_sequence_DomainManager
typedef struct CORBA_sequence_DomainManager CORBA_DomainManagerList;

#define _typedef___PortableServer_sequence_octet
typedef struct PortableServer_sequence_octet PortableServer_ObjectId;


/* Moved from orbit_types.h */
typedef CORBA_sequence_octet CORBA_Principal;
typedef CORBA_sequence_octet CORBA_DynAny_OctetSeq;
typedef CORBA_sequence_octet CORBA_DynFixed_OctetSeq;
typedef CORBA_sequence_octet CORBA_DynEnum_OctetSeq;
typedef CORBA_sequence_octet CORBA_DynStruct_OctetSeq;
typedef CORBA_sequence_octet CORBA_DynUnion_OctetSeq;
typedef CORBA_sequence_octet CORBA_DynSequence_OctetSeq;
typedef CORBA_sequence_octet CORBA_DynArray_OctetSeq;
typedef CORBA_sequence_Identifier CORBA_EnumMemberSeq;


#endif /* !_ORBIT_CORBA_SEQUENCES_H_ */

==> ORBit-0.4.93.tar.gz: ORBit-0.4.93/src/orb/corba_sequences.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  ORBit: A CORBA v2.2 ORB
 *
 *  Copyright (C) 1998 Richard H. Porter
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Library General Public
 *  License as published by the Free Software Foundation; either
 *  version 2 of the License, or (at your option) any later version.
 *
 *  This library is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Library General Public License for more details.
 *
 *  You should have received a copy of the GNU Library General Public
 *  License along with this library; if not, write to the Free
 *  Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *  Author: Dick Porter <dick@cymru.net>
 *
 */

#ifndef _ORBIT_CORBA_SEQUENCES_H_
#define _ORBIT_CORBA_SEQUENCES_H_


/* moved from sequences.h */
#include "corba_basic_sequences_type.h"

typedef CORBA_sequence_octet CORBA_ReferenceData;

#define _CORBA_sequence_ServiceOption_defined
typedef struct CORBA_sequence_ServiceOption CORBA_sequence_ServiceOption;

#define _CORBA_sequence_ServiceDetail_defined
typedef struct CORBA_sequence_ServiceDetail CORBA_sequence_ServiceDetail;

#define _CORBA_sequence_ORB_ObjectId_defined
typedef struct CORBA_sequence_ORB_ObjectId CORBA_ORB_ObjectIdList;

#define _CORBA_sequence_NameValuePair_defined
typedef struct CORBA_sequence_NameValuePair CORBA_NameValuePairSeq;

#define _CORBA_sequence_CORBA_any_defined
typedef struct CORBA_sequence_CORBA_any CORBA_AnySeq;

#define _CORBA_sequence_Policy_defined
typedef struct CORBA_sequence_Policy CORBA_PolicyList;

#define _CORBA_sequence_DomainManager_defined
typedef struct CORBA_sequence_DomainManager CORBA_DomainManagerList;

#define _PortableServer_sequence_octet_defined
typedef struct PortableServer_sequence_octet PortableServer_ObjectId;


/* Moved from orbit_types.h */
#ifndef HAVE_CORBA_PRINCIPAL
#define HAVE_CORBA_PRINCIPAL 1
typedef CORBA_sequence_octet CORBA_Principal;
#endif
typedef CORBA_sequence_octet CORBA_DynAny_OctetSeq;
typedef CORBA_sequence_octet CORBA_DynFixed_OctetSeq;
typedef CORBA_sequence_octet CORBA_DynEnum_OctetSeq;
typedef CORBA_sequence_octet CORBA_DynStruct_OctetSeq;
typedef CORBA_sequence_octet CORBA_DynUnion_OctetSeq;
typedef CORBA_sequence_octet CORBA_DynSequence_OctetSeq;
typedef CORBA_sequence_octet CORBA_DynArray_OctetSeq;

#endif /* !_ORBIT_CORBA_SEQUENCES_H_ */
